==> testsuite-1.0.11-beta1.tar.gz: testsuite/tests_module/custom_tests/src/CustomTSTests/MicrosoftConnectionTest.php <==
<?php

namespace Drupal\custom_tests\Tests;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\testsuite\TestInterface;
use Drupal\testsuite\TestBase;
use Symfony\Component\HttpFoundation\Request;

use Drupal\tmgmt\TMGMTException;
use GuzzleHttp\Exception\BadResponseException;
use Drupal\tmgmt\Translator\AvailableResult;

class MicrosoftConnectionTest extends TestBase implements TestInterface {
    use StringTranslationTrait;

    private $translateUrl = 'https://api.cognitive.microsofttranslator.com';
    private $tokenUrl = 'https://api.cognitive.microsoft.com/sts/v1.0/issueToken/';

    private $_moduleName = "tmgmt_microsoft";

    private $_menuName = "Configuration";

    private $_name = "Microsoft Connection Test";

    private $_description = "Checks the Microsoft Translation keys to make sure they are active.";

    public function getModuleName() {
        return $this->_moduleName;
    }

    public function getMenuName() {
        return $this->_menuName;
    }

    public function getName() {
        return $this->_name;
    }

    public function getDescription() {
        return $this->_description;
    }

    public function runTest(Request $request)
    {
        $config = \Drupal::config('tmgmt.translator.microsoft');
        $key = isset($config->get('settings')['microsoft_api_key']) ? $config->get('settings')['microsoft_api_key'] : "";
        $region = isset($config->get('settings')['microsoft_api_region']) ? $config->get('settings')['microsoft_api_region'] : "";
        if ($key && $region) {
            try {
                $this->getToken($key, $region);
                return t('Test Passed');
            }
            catch (TMGMTException $e) {
                return AvailableResult::no(t('Microsoft is not available. The key is invalid.'))->getReason();
            }

        }
        return AvailableResult::no(t('Microsoft is not available. Not key configured.'))->getReason();
    }

    /**
     * Get the access token.
     *
     * @param string $api_key
     *   Microsoft Azure API key.
     *
     * @return string
     *   The access token.
     *
     * @throws \Drupal\tmgmt\TMGMTException
     *   Thrown when the API key is missing or not valid.
     */
    public function getToken($api_key, $api_region) {
        $client = \Drupal::service('testsuite.guzzle.service')->getService();
        if (!$api_key) {
            throw new TMGMTException('Missing API key.');
        }

        $url = str_replace('api', $api_region.'.api', $this->tokenUrl);
        $headers = [
            'Content-Type' => 'application/json',
            'Ocp-Apim-Subscription-Key' => $api_key
        ];

        try {
            $response = $client->request('POST', $url, ['headers' => $headers]);
        }
        catch (BadResponseException $e) {
            $error = json_decode((string) $e->getResponse()->getBody());
            $message = property_exists($error, 'message') ? $error->message : 'n/a';
            throw new TMGMTException('Microsoft Translate service returned the following error: @error', ['@error' => $message]);
        }
        return (string) $response->getBody();
    }
}

==> testsuite-3.0.13-beta1.tar.gz: testsuite/tests_module/custom_tests/src/CustomTSTests/MicrosoftConnectionTest.php <==
<?php

namespace Drupal\custom_tests\Tests;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\testsuite\TestInterface;
use Symfony\Component\HttpFoundation\Request;

use Drupal\tmgmt\TMGMTException;
use GuzzleHttp\Exception\BadResponseException;
use Drupal\tmgmt\Translator\AvailableResult;

class MicrosoftConnectionTest implements TestInterface {
    use StringTranslationTrait;

    /**
     * @var string $translateUrl
     */
    private $translateUrl = 'https://api.cognitive.microsofttranslator.com';

    /**
     * @var string $tokenUrl
     */
    private $tokenUrl = 'https://api.cognitive.microsoft.com/sts/v1.0/issueToken/';

    /**
     * @var string $_moduleName
     */
    private $_moduleName = "tmgmt_microsoft";

    /**
     * @var string $_menuName
     */
    private $_menuName = "Configuration";

    /**
     * @var string $_name
     */
    private $_name = "Microsoft Connection Test";

    /**
     * @var string $_description
     */
    private $_description = "Checks the Microsoft Translation keys to make sure they are active.";

    /**
     * Getter for $_moduleName
     *
     * @return string $_moduleName
     */
    public function getModuleName() {
        return $this->_moduleName;
    }

    /**
     * Getter for $_menuName
     *
     * @return string $_menuName
     */
    public function getMenuName() {
        return $this->_menuName;
    }

    /**
     * Getter for $_name
     *
     * @return string $_name
     */
    public function getName() {
        return $this->_name;
    }

    /**
     * Getter for $_description
     *
     * @return string $_description
     */
    public function getDescription() {
        return $this->_description;
    }

    /**
     * Tests that Tmgmt Mcrosoft Translation keys are good.
     */
    public function runTest(Request $request)
    {
        $config = \Drupal::config('tmgmt.translator.microsoft');
        $key = isset($config->get('settings')['microsoft_api_key']) ? $config->get('settings')['microsoft_api_key'] : "";
        $region = isset($config->get('settings')['microsoft_api_region']) ? $config->get('settings')['microsoft_api_region'] : "";
        if ($key && $region) {
            try {
                $this->getToken($key, $region);
                return t('Test Passed');
            }
            catch (TMGMTException $e) {
                return AvailableResult::no(t('Microsoft is not available. The key is invalid.'))->getReason();
            }

        }
        return AvailableResult::no(t('Microsoft is not available. Not key configured.'))->getReason();
    }

    /**
     * Get the access token.
     *
     * @param string $api_key
     *   Microsoft Azure API key.
     *
     * @return string
     *   The access token.
     *
     * @throws \Drupal\tmgmt\TMGMTException
     *   Thrown when the API key is missing or not valid.
     */
    public function getToken($api_key, $api_region) {
        $client = \Drupal::service('testsuite.guzzle.service')->getService();
        if (!$api_key) {
            throw new TMGMTException('Missing API key.');
        }

        $url = str_replace('api', $api_region.'.api', $this->tokenUrl);
        $headers = [
            'Content-Type' => 'application/json',
            'Ocp-Apim-Subscription-Key' => $api_key
        ];

        try {
            $response = $client->request('POST', $url, ['headers' => $headers]);
        }
        catch (BadResponseException $e) {
            $error = json_decode((string) $e->getResponse()->getBody());
            $message = property_exists($error, 'message') ? $error->message : 'n/a';
            throw new TMGMTException('Microsoft Translate service returned the following error: @error', ['@error' => $message]);
        }
        return (string) $response->getBody();
    }
}
